@@ -4,7 +4,7 @@ use Imager;
 use Imager::Expr::Assem;
 use vars qw($VERSION);
 
-$VERSION = "1.005";
+$VERSION = "1.006";
 
 my %funcs =
   (
@@ -531,4 +531,8 @@ Needs more transformations.
 
 Imager(3), F<transform.perl>
 
+=head1 AUTHOR
+
+Tony Cook <tonyc@cpan.org>
+
 =cut
